import { type Job, type RegularStep } from "github-actions-cdk";
/**
 * Base class for providing Docker credentials to various registry types.
 *
 * @remarks
 * The `DockerCredentials` class provides a unified interface for handling Docker login credentials
 * across different registry providers (e.g., DockerHub, ECR, GHCR). Concrete implementations of
 * this class define specific registry login steps.
 */
export declare abstract class DockerCredentials {
    /**
     * Creates a `DockerCredentials` instance for DockerHub.
     *
     * @param props - The properties for configuring DockerHub credentials.
     * @returns An instance of `DockerHubCredentials` configured with the specified properties.
     */
    static dockerHub(props: DockerHubCredentialsProps): DockerCredentials;
    /**
     * Creates a `DockerCredentials` instance for AWS ECR.
     *
     * @param props - The properties for configuring ECR credentials.
     * @returns An instance of `EcrCredentials` configured with the specified properties.
     */
    static ecr(props: EcrCredentialsProps): DockerCredentials;
    /**
     * Creates a `DockerCredentials` instance for GitHub Container Registry (GHCR).
     *
     * @returns An instance of `GhcrCredentials`.
     */
    static ghcr(): DockerCredentials;
    /**
     * Creates a `DockerCredentials` instance for a custom Docker registry.
     *
     * @param props - The properties for configuring custom registry credentials.
     * @returns An instance of `CustomProvider` configured with the specified properties.
     */
    static customRegistry(props: CustomProviderProps): DockerCredentials;
    /**
     * Returns Docker login steps required for the specified job.
     *
     * @param job - The GitHub Actions job for which Docker login steps are generated.
     * @returns An array of `RegularStep` instances for Docker authentication.
     */
    abstract credentialSteps(job: Job): RegularStep[];
}
/**
 * Properties required for DockerHub credentials.
 *
 * @remarks
 * These properties allow for configuration of DockerHub login credentials, typically provided
 * as environment variables or secrets within the GitHub Actions workflow.
 */
export interface DockerHubCredentialsProps {
    /** Environment variable key for the DockerHub username. Defaults to "DOCKERHUB_USERNAME". */
    readonly usernameKey?: string;
    /** Environment variable key for the DockerHub access token. Defaults to "DOCKERHUB_TOKEN". */
    readonly personalAccessTokenKey?: string;
}
/**
 * Properties required for AWS ECR credentials.
 *
 * @remarks
 * Used to configure ECR credentials for authenticating against an AWS Elastic Container Registry.
 */
export interface EcrCredentialsProps {
    /** The ECR registry URL, required for connecting to a specific AWS ECR instance. */
    readonly registry: string;
}
/**
 * Properties required for a custom Docker registry.
 *
 * @remarks
 * Configures the necessary properties for authenticating to a non-standard or third-party Docker registry.
 */
export interface CustomProviderProps {
    /** The registry URL. */
    readonly registry: string;
    /** Environment variable key for the registry username. */
    readonly usernameKey: string;
    /** Environment variable key for the registry password. */
    readonly passwordKey: string;
}
